=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-12-31 06:43:08 +0000
+++ drizzled/session.h	2010-12-31 21:25:11 +0000
@@ -668,9 +668,16 @@
 public:
 
   time_t start_time;
+private:
   time_t user_time;
   uint64_t start_utime;
-  uint64_t utime_after_lock;
+public:
+  uint64_t utime_after_lock; // This used by Innodb.
+
+  void resetUserTime()
+  {
+    user_time= 0;
+  }
 
   thr_lock_type update_lock_default;
 
@@ -1269,7 +1276,7 @@
     }
   }
 
-  void set_time(time_t t)
+  void set_time(time_t t) // This is done by a sys_var, as long as user_time is set, we will use that for all references to time
   {
     start_time= user_time= t;
     boost::posix_time::ptime mytime(boost::posix_time::microsec_clock::universal_time());
@@ -1290,6 +1297,11 @@
     status_var.execution_time_nsec+=(_end_timer - _start_timer).total_microseconds();
   }
 
+  uint64_t getElapsedTime() const
+  {
+    return (_end_timer - _start_timer).total_microseconds();
+  }
+
   /**
    * Returns the current micro-timestamp
    */

=== modified file 'drizzled/sys_var.cc'
--- drizzled/sys_var.cc	2010-12-18 04:43:40 +0000
+++ drizzled/sys_var.cc	2010-12-31 21:25:11 +0000
@@ -1158,7 +1158,7 @@
 
 void sys_var_timestamp::set_default(Session *session, sql_var_t)
 {
-  session->user_time=0;
+  session->resetUserTime();
 }
 
 

=== modified file 'plugin/logging_query/logging_query.cc'
--- plugin/logging_query/logging_query.cc	2010-12-31 06:43:08 +0000
+++ plugin/logging_query/logging_query.cc	2010-12-31 21:25:11 +0000
@@ -241,7 +241,7 @@
     */
     uint64_t t_mark= session->getCurrentTimestamp(false);
 
-    if ((t_mark - session->start_utime) < (sysvar_logging_query_threshold_slow.get()))
+    if (session->getElapsedTime() < (sysvar_logging_query_threshold_slow.get()))
       return false;
 
     Session::QueryString query_string(session->getQueryString());
@@ -273,7 +273,7 @@
               % qs
               % command_name[session->command].str
               % (t_mark - session->getConnectMicroseconds())
-              % (t_mark - session->start_utime)
+              % session->getElapsedTime()
               % (t_mark - session->utime_after_lock)
               % session->sent_row_count
               % session->examined_row_count

=== modified file 'plugin/syslog/logging.cc'
--- plugin/syslog/logging.cc	2010-12-31 06:43:08 +0000
+++ plugin/syslog/logging.cc	2010-12-31 21:25:11 +0000
@@ -85,7 +85,7 @@
   uint64_t t_mark= session->getCurrentTimestamp(false);
 
   // return if query was not too slow
-  if ((t_mark - session->start_utime) < _threshold_slow)
+  if (session->getElapsedTime() < _threshold_slow)
     return false;
   
   drizzled::Session::QueryString query_string(session->getQueryString());
@@ -109,7 +109,7 @@
          (int) drizzled::command_name[session->command].length,
          drizzled::command_name[session->command].str,
          (unsigned long long) (t_mark - session->getConnectMicroseconds()),
-         (unsigned long long) (t_mark - session->start_utime),
+         (unsigned long long) (session->getElapsedTime()),
          (unsigned long long) (t_mark - session->utime_after_lock),
          (unsigned long) session->sent_row_count,
          (unsigned long) session->examined_row_count,

